==> libreoffice_7.3.7.orig.tar.xz: libreoffice-7.3.7.2/lotuswordpro/source/filter/xfilter/xftextboxstyle.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
 *
 *  The Contents of this file are made available subject to the terms of
 *  either of the following licenses
 *
 *         - GNU Lesser General Public License Version 2.1
 *         - Sun Industry Standards Source License Version 1.1
 *
 *  Sun Microsystems Inc., October, 2000
 *
 *  GNU Lesser General Public License Version 2.1
 *  =============================================
 *  Copyright 2000 by Sun Microsystems, Inc.
 *  901 San Antonio Road, Palo Alto, CA 94303, USA
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 *
 *
 *  Sun Industry Standards Source License Version 1.1
 *  =================================================
 *  The contents of this file are subject to the Sun Industry Standards
 *  Source License Version 1.1 (the "License"); You may not use this file
 *  except in compliance with the License. You may obtain a copy of the
 *  License at http://www.openoffice.org/license.html.
 *
 *  Software provided under this License is provided on an "AS IS" basis,
 *  WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING,
 *  WITHOUT LIMITATION, WARRANTIES THAT THE SOFTWARE IS FREE OF DEFECTS,
 *  MERCHANTABLE, FIT FOR A PARTICULAR PURPOSE, OR NON-INFRINGING.
 *  See the License for the specific provisions governing your rights and
 *  obligations concerning the Software.
 *
 *  The Initial Developer of the Original Code is: IBM Corporation
 *
 *  Copyright: 2008 by IBM Corporation
 *
 *  All Rights Reserved.
 *
 *  Contributor(s): _______________________________________
 *
 *
 ************************************************************************/
#include <xfilter/ixfattrlist.hxx>
#include <xfilter/xftextboxstyle.hxx>

XFTextBoxStyle::XFTextBoxStyle()
{
}

XFTextBoxStyle::~XFTextBoxStyle()
{
}

enumXFStyle XFTextBoxStyle::GetStyleFamily()
{
    return enumXFStyleGraphics;
}

void    XFTextBoxStyle::ToXml(IXFStream *pStrm)
{
    IXFAttrList *pAttrList = pStrm->GetAttrList();

    pAttrList->Clear();
    pAttrList->AddAttribute( "style:name", GetStyleName() );
    if( !GetParentStyleName().isEmpty() )
        pAttrList->AddAttribute("style:parent-style-name",GetParentStyleName());
    pAttrList->AddAttribute( "style:family", "graphics" );
    //parent style name ignore now.
    pStrm->StartElement( "style:style" );

    pAttrList->Clear();
    pAttrList->AddAttribute( "draw:stroke", "none" );
    pAttrList->AddAttribute( "svg:stroke-color", "#000000" );
    pAttrList->AddAttribute( "draw:fill", "none" );
    pAttrList->AddAttribute( "draw:fill-color", "#ffffff" );
    pAttrList->AddAttribute( "draw:auto-grow-height", "true" );
    pAttrList->AddAttribute( "style:run-through", "foreground" );
    pAttrList->AddAttribute( "style:wrap", "run-through" );
    pAttrList->AddAttribute( "style:wrap", "run-through" );
    pAttrList->AddAttribute( "style:number-wrapped-paragraphs", "no-limit" );
    pAttrList->AddAttribute( "style:wrap-contour", "false" );

    pStrm->StartElement( "style:properties" );
    pStrm->EndElement( "style:properties" );

    pStrm->EndElement( "style:style" );
}
/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_25.8.3.orig.tar.xz: libreoffice-25.8.3.2/lotuswordpro/source/filter/xfilter/xftextboxstyle.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
 *
 *  The Contents of this file are made available subject to the terms of
 *  either of the following licenses
 *
 *         - GNU Lesser General Public License Version 2.1
 *         - Sun Industry Standards Source License Version 1.1
 *
 *  Sun Microsystems Inc., October, 2000
 *
 *  GNU Lesser General Public License Version 2.1
 *  =============================================
 *  Copyright 2000 by Sun Microsystems, Inc.
 *  901 San Antonio Road, Palo Alto, CA 94303, USA
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 *
 *
 *  Sun Industry Standards Source License Version 1.1
 *  =================================================
 *  The contents of this file are subject to the Sun Industry Standards
 *  Source License Version 1.1 (the "License"); You may not use this file
 *  except in compliance with the License. You may obtain a copy of the
 *  License at http://www.openoffice.org/license.html.
 *
 *  Software provided under this License is provided on an "AS IS" basis,
 *  WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING,
 *  WITHOUT LIMITATION, WARRANTIES THAT THE SOFTWARE IS FREE OF DEFECTS,
 *  MERCHANTABLE, FIT FOR A PARTICULAR PURPOSE, OR NON-INFRINGING.
 *  See the License for the specific provisions governing your rights and
 *  obligations concerning the Software.
 *
 *  The Initial Developer of the Original Code is: IBM Corporation
 *
 *  Copyright: 2008 by IBM Corporation
 *
 *  All Rights Reserved.
 *
 *  Contributor(s): _______________________________________
 *
 *
 ************************************************************************/
#include <xfilter/ixfattrlist.hxx>
#include <xfilter/xftextboxstyle.hxx>

XFTextBoxStyle::XFTextBoxStyle()
{
}

XFTextBoxStyle::~XFTextBoxStyle()
{
}

enumXFStyle XFTextBoxStyle::GetStyleFamily()
{
    return enumXFStyleGraphics;
}

void    XFTextBoxStyle::ToXml(IXFStream *pStrm)
{
    IXFAttrList *pAttrList = pStrm->GetAttrList();

    pAttrList->Clear();
    pAttrList->AddAttribute( u"style:name"_ustr, GetStyleName() );
    if( !GetParentStyleName().isEmpty() )
        pAttrList->AddAttribute(u"style:parent-style-name"_ustr,GetParentStyleName());
    pAttrList->AddAttribute( u"style:family"_ustr, u"graphics"_ustr );
    //parent style name ignore now.
    pStrm->StartElement( u"style:style"_ustr );

    pAttrList->Clear();
    pAttrList->AddAttribute( u"draw:stroke"_ustr, u"none"_ustr );
    pAttrList->AddAttribute( u"svg:stroke-color"_ustr, u"#000000"_ustr );
    pAttrList->AddAttribute( u"draw:fill"_ustr, u"none"_ustr );
    pAttrList->AddAttribute( u"draw:fill-color"_ustr, u"#ffffff"_ustr );
    pAttrList->AddAttribute( u"draw:auto-grow-height"_ustr, u"true"_ustr );
    pAttrList->AddAttribute( u"style:run-through"_ustr, u"foreground"_ustr );
    pAttrList->AddAttribute( u"style:wrap"_ustr, u"run-through"_ustr );
    pAttrList->AddAttribute( u"style:wrap"_ustr, u"run-through"_ustr );
    pAttrList->AddAttribute( u"style:number-wrapped-paragraphs"_ustr, u"no-limit"_ustr );
    pAttrList->AddAttribute( u"style:wrap-contour"_ustr, u"false"_ustr );

    pStrm->StartElement( u"style:properties"_ustr );
    pStrm->EndElement( u"style:properties"_ustr );

    pStrm->EndElement( u"style:style"_ustr );
}
/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
